Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9359)

Unified Diff: chromecast/media/cma/backend/video_plane.h

Issue 878843004: Chromecast: update VideoPlane CoordinateType list. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromecast/media/cma/backend/video_plane.h
diff --git a/chromecast/media/cma/backend/video_plane.h b/chromecast/media/cma/backend/video_plane.h
index 6c98d29c59fd8109514750fc2859b16a166a7858..a5f864c6d500ce5e1805e31a12cc36c037f0463d 100644
--- a/chromecast/media/cma/backend/video_plane.h
+++ b/chromecast/media/cma/backend/video_plane.h
@@ -21,9 +21,8 @@ class VideoPlane {
enum CoordinateType {
// Graphics plane as coordinate type.
COORDINATE_TYPE_GRAPHICS_PLANE = 0,
-
- // Output video plane as coordinate type.
- COORDINATE_TYPE_VIDEO_PLANE_RESOLUTION = 1,
+ // Output display screen as coordinate type.
+ COORDINATE_TYPE_SCREEN_RESOLUTION = 1,
};
VideoPlane();
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698